import logging

from spaceone.core import cache
from spaceone.core import config
from spaceone.core.manager import BaseManager
from spaceone.core.connector.space_connector import SpaceConnector
from spaceone.core.auth.jwt.jwt_util import JWTUtil

_LOGGER = logging.getLogger(__name__)


class ConfigManager(BaseManager):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        token = self.transaction.get_meta("token")
        self.token_type = JWTUtil.get_value_from_token(token, "typ")
        self.config_conn: SpaceConnector = self.locator.get_connector(
            SpaceConnector, service="config"
        )

    @cache.cacheable(
        key="board:domain-config-settings:{domain_id}:settings", expire=300
    )
    def get_domain_config(self, domain_id: str):
        if self.token_type == "SYSTEM_TOKEN":
            response = self.config_conn.dispatch(
                "DomainConfig.get",
                {"name": "settings"},
                x_domain_id=domain_id,
            )
        else:
            response = self.config_conn.dispatch(
                "DomainConfig.get",
                {"name": "settings"},
            )
        return response



import logging
import os

from jinja2 import Environment, FileSystemLoader, select_autoescape

from spaceone.core import config
from spaceone.core.manager import BaseManager
from spaceone.board.connector.smtp_connector import SMTPConnector

_LOGGER = logging.getLogger(__name__)

TEMPLATE_PATH = os.path.join(os.path.dirname(__file__), f"../template")
JINJA_ENV = Environment(
    loader=FileSystemLoader(searchpath=TEMPLATE_PATH), autoescape=select_autoescape()
)


class EmailManager(BaseManager):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.smtp_connector = SMTPConnector()

    def send_notification_email(
        self, email: str, language: str, post_contents: str, post_title: str
    ):
        service_name = self._get_service_name()
        template = JINJA_ENV.get_template(f"notice_email_{language}.html")
        email_contents = template.render(
            markdown=post_contents,
            service_name=service_name,
            notice_title=post_title,
        )
        subject = f"[{service_name}] {post_title}"

        self.smtp_connector.send_email(email, subject, email_contents)

    @staticmethod
    def _get_service_name():
        return config.get_global("EMAIL_SERVICE_NAME")
